@@ -3,8 +3,10 @@
 
 extern crate libc;
 
+#[cfg(not(target_env = "msvc"))]
 extern crate libz_sys;
-#[cfg(unix)] extern crate openssl_sys;
+#[cfg(unix)]
+extern crate openssl_sys;
 
 use libc::{c_int, size_t, c_void, c_char, c_long, c_uchar, c_uint, c_ulong};
 use libc::ssize_t;
